@@ -4,7 +4,7 @@ from decimal import Decimal
 from functools import reduce
 from itertools import product
 from pathlib import Path
-from typing import Dict, Iterator, List, Set, Tuple, Union
+from typing import Any, Dict, Iterator, List, Set, Tuple, Union
 
 from parsimonious import Grammar, NodeVisitor, ParseError
 from parsimonious.nodes import Node
@@ -24,7 +24,6 @@ from jubeatools.song import (
 from jubeatools.utils import none_or
 
 from ..command import is_command, parse_command
-from ..files import load_files
 from ..load_tools import (
     CIRCLE_FREE_TO_BEATS_TIME,
     JubeatAnalyserParser,
@@ -32,6 +31,7 @@ from ..load_tools import (
     find_long_note_candidates,
     is_empty_line,
     is_separator,
+    load_folder,
     pick_correct_long_note_candidates,
     split_double_byte_line,
 )
@@ -241,10 +241,10 @@ class MonoColumnParser(JubeatAnalyserParser):
             section_starting_beat += section.length
 
 
-def load_mono_column(path: Path) -> Song:
-    files = load_files(path)
+def load_mono_column(path: Path, **kwargs: Any) -> Song:
+    files = load_folder(path)
     charts = [_load_mono_column_file(lines) for _, lines in files.items()]
-    return reduce(lambda a, b: a.merge(b), charts)
+    return reduce(Song.merge, charts)
 
 
 def _load_mono_column_file(lines: List[str]) -> Song:
