@@ -30,7 +30,7 @@ data = (
                 ],
             )
         },
-        global_timing=None,
+        common_timing=None,
     ),
     False,
 )
